# Welcome to JAQK financial report package
> A light and useful toolkit developed for financial report getter and basic analysis and calculations.

> It starts with an assignment, proceeds with deadlines, and grows with passions. - Hanbo Guo

_Author: Hanbo Guo_

_Facility: High School Afflicated to Renmin University of China_

_Contact: hbopublic@163.com_


## What's this

**JAQK** is a Python tookit providing light and robust data collection and data processing for quantitative analysis for US stocks. JAQK aims to tackle the problem of gathering financial data for high school students, and we hope JAQK can help some basic level of quantitative analysis. 

## Installations
For quick installation with **PyPI**:
```sh
# PyPI 
pip install jaqk
```
and you can **upgrade** the package with:
```sh
# PyPI upgrade
pip install jaqk --upgrade
```
You can also set up the package after downloading the package from this site:
```sh
# install after downloading
python setup.py install
```

## Dependency
- Python 3.4 or more
- For data collection
  - [requests](https://2.python-requests.org//en/master/)
  - [pyquery](https://pyquery.readthedocs.io/en/latest/)
  - [aiohttp](https://aiohttp.readthedocs.io/en/stable/)
  - [selenium](https://selenium-python.readthedocs.io) (optional; it will be changed to pypeppter)
- For data processing
  - [pandas](http://pandas.pydata.org/ "pandas")
  - [numpy](http://www.numpy.org)
- Other necessary
  - [pysimplegui](https://pysimplegui.readthedocs.io/en/latest/)
  
## Documentation
The official documentation is hosted by [github.io]().
  
## Getting help
For usage questions, the best place to go to is [StackOverflow](https://stackoverflow.com/questions/tagged/JAQK);
Further, general questions and discussions can also take place on the github [issues section](https://github.com/Haannbboo/JAQK/issues).

If you have any detailed question about the plan/design/develop of this tookit, feel free to contact me through my email.

## Previous Updates

All changes (pushes) have been recorded [here](https://github.com/Haannbboo/JAQK/blob/master/jaqk/HISVERSION.md). Click for more details.
  
